'use client';

import {
  Box,
  Container,
  Heading,
  Text,
  VStack,
  useColorModeValue,
  StackDivider,
} from '@chakra-ui/react';

export default function PrivacyPolicyPage() {
  const bg = useColorModeValue('white', 'gray.800');
  const headingColor = useColorModeValue('teal.600', 'teal.300');
  const textColor = useColorModeValue('gray.700', 'gray.300');

  return (
   <Box
      minH="100vh"
      bgGradient="linear(to-br, teal.50, white)"
      py={{ base: 10, md: 20 }}
      px={{ base: 4, md: 0 }}
      display="flex"
      alignItems="center"
      justifyContent="center"
    >
      <Container maxW="7xl" bg={bg} boxShadow="2xl" borderRadius="xl" p={{ base: 8, md: 16 }}>
        <Heading
          as="h1"
          size="2xl"
          mb={8}
          fontWeight="extrabold"
          color={headingColor}
          letterSpacing="tight"
          textAlign="center"
        >
          Privacy Policy
        </Heading>

        <VStack
          spacing={6}
          align="stretch"
          divider={<StackDivider borderColor={useColorModeValue('gray.200', 'gray.700')} />}
          color={textColor}
          fontSize="md"
          lineHeight="tall"
        >
          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              1. Introduction
            </Heading>
            <Text>
              We respect your privacy and are committed to protecting your personal data. This
              Privacy Policy explains how we collect, use, and safeguard your information when you
              visit our website.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              2. Information We Collect
            </Heading>
            <Text>
              We may collect personal information such as your name, email address, and other
              details when you contact us or use our services. We also collect non-personal
              information through cookies and analytics tools to improve your experience.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              3. How We Use Your Information
            </Heading>
            <Text>
              The information we collect is used to provide, maintain, and improve our services,
              respond to inquiries, send important updates, and for security purposes.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              4. Sharing Your Information
            </Heading>
            <Text>
              We do not sell or rent your personal data. We may share information with trusted
              service providers who assist us in operating our website and services under strict
              confidentiality agreements.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              5. Cookies and Tracking Technologies
            </Heading>
            <Text>
              Our website uses cookies to enhance your browsing experience. You can control cookie
              settings through your browser preferences.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              6. Your Rights
            </Heading>
            <Text>
              You have the right to access, correct, or delete your personal information. Contact us
              if you want to exercise these rights or have questions about your data.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              7. Security
            </Heading>
            <Text>
              We implement appropriate security measures to protect your data from unauthorized
              access or disclosure.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              8. Changes to This Policy
            </Heading>
            <Text>
              We may update this Privacy Policy periodically. We encourage you to review this page
              regularly for any changes.
            </Text>
          </Box>

          <Box>
            <Heading as="h2" size="lg" mb={3} color={headingColor}>
              9. Contact Us
            </Heading>
            <Text>
              If you have any questions or concerns about this Privacy Policy, please contact us at{' '}
              <a
                href="mailto:privacy@yourwebsite.com"
                style={{ color: headingColor, textDecoration: 'underline' }}
              >
                privacy@yourwebsite.com
              </a>
              .
            </Text>
          </Box>
        </VStack>
      </Container>
    </Box>
  );
}
